@@ -307,7 +307,7 @@ class Cart(ModelSQL):
             'website': request.nereid_website.id,
             'nereid_user': user.id,
             'warehouse': request.nereid_website.warehouse.id,
-            'payment_term': request.nereid_website.payment_term,
+            'payment_term': request.nereid_website.payment_term.id,
         }
         self.sale = Sale.create([sale_values])[0]
         self.save()
@@ -349,6 +349,11 @@ class Cart(ModelSQL):
             sale_line = cart.sale._add_or_update(
                 form.product.data, form.quantity.data, action
             )
+
+            # Validate that product availability in inventory is not less than
+            # warehouse quantity
+            sale_line.validate_for_product_inventory()
+
             sale_line.save()
 
             if action == 'add':
