@@ -17,6 +17,7 @@ import pycountry
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import POOL, USER, DB_NAME, CONTEXT
 from nereid.testing import NereidTestCase
+from werkzeug.datastructures import Headers
 from trytond.transaction import Transaction
 from trytond.config import config
 
@@ -34,12 +35,13 @@ class BaseTestCase(NereidTestCase):
         self.Company = POOL.get('company.company')
         self.Party = POOL.get('party.party')
         self.Sale = POOL.get('sale.sale')
+        self.ShipmentOut = POOL.get('stock.shipment.out')
         self.Cart = POOL.get('nereid.cart')
         self.Product = POOL.get('product.product')
         self.ProductTemplate = POOL.get('product.template')
         self.Language = POOL.get('ir.lang')
         self.NereidWebsite = POOL.get('nereid.website')
-        self.SaleShop = POOL.get('sale.shop')
+        self.SaleChannel = POOL.get('sale.channel')
         self.Uom = POOL.get('product.uom')
         self.Country = POOL.get('country.country')
         self.Subdivision = POOL.get('country.subdivision')
@@ -248,7 +250,7 @@ class BaseTestCase(NereidTestCase):
         """
         return self.NereidWebsite.create([{
             'name': 'localhost',
-            'shop': self.shop,
+            'channel': self.channel,
             'company': self.company.id,
             'application_user': USER,
             'default_locale': self.locale_en_us.id,
@@ -289,13 +291,13 @@ class BaseTestCase(NereidTestCase):
                 'party': self.party.id,
                 'currency': self.usd
             }])
-
         self.User.write(
             [self.User(USER)], {
                 'main_company': self.company.id,
                 'company': self.company.id,
             }
         )
+
         CONTEXT.update(self.User.get_preferences(context_only=True))
 
         # Create Fiscal Year
@@ -305,7 +307,7 @@ class BaseTestCase(NereidTestCase):
         # Create a payment term
         payment_term, = self._create_payment_term()
 
-        shop_price_list, user_price_list = self._create_pricelists()
+        channel_price_list, user_price_list = self._create_pricelists()
 
         party1, = self.Party.create([{
             'name': 'Guest User',
@@ -314,6 +316,9 @@ class BaseTestCase(NereidTestCase):
         party2, = self.Party.create([{
             'name': 'Registered User',
             'sale_price_list': user_price_list,
+            'addresses': [('create', [{
+                'name': 'An Address',
+            }])],
         }])
 
         party3, = self.Party.create([{
@@ -371,15 +376,31 @@ class BaseTestCase(NereidTestCase):
         }])
 
         with Transaction().set_context(company=self.company.id):
-            self.shop, = self.SaleShop.create([{
-                'name': 'Default Shop',
-                'price_list': shop_price_list,
+            self.channel, = self.SaleChannel.create([{
+                'name': 'Default Channel',
+                'price_list': channel_price_list,
+                'invoice_method': 'order',
+                'shipment_method': 'order',
+                'source': 'webshop',
+                'create_users': [('add', [USER])],
                 'warehouse': warehouse,
                 'payment_term': payment_term,
                 'company': self.company.id,
-                'users': [('add', [USER])]
+                'default_account_expense':
+                    self._get_account_by_kind('expense').id,
+                'default_account_revenue':
+                    self._get_account_by_kind('revenue').id,
             }])
-        self.User.set_preferences({'shop': self.shop})
+
+        self.User.set_preferences({'current_channel': self.channel})
+
+        self.User.write(
+            [self.User(USER)], {
+                'main_company': self.company.id,
+                'company': self.company.id,
+                'current_channel': self.channel,
+            }
+        )
 
         self.create_website()
 
@@ -567,6 +588,8 @@ class TestProduct(BaseTestCase):
         """
         Test serialize() method.
         """
+        Media = POOL.get('product.media')
+
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             self.setup_defaults()
             uom, = self.Uom.search([], limit=1)
@@ -588,17 +611,21 @@ class TestProduct(BaseTestCase):
                 'sale_uom': uom.id,
                 'account_expense': self._get_account_by_kind('expense').id,
                 'account_revenue': self._get_account_by_kind('revenue').id,
+                'media': [('create', [{
+                    'static_file': file1.id,
+                }])],
             }])
 
             product, = product_template.products
             product.displayed_on_eshop = True
-            product.uri = 'uri1'
+            product.uri = 'uri'
             product.save()
 
-            file1.product = product
-            file2.product = product
-            file1.save()
-            file2.save()
+            product_media = Media(**{
+                'static_file': file2.id,
+                'product': product.id,
+            })
+            product_media.save()
 
             qty = 7
 
@@ -647,6 +674,78 @@ class TestProduct(BaseTestCase):
                     lines[0]['display_name'], product.name
                 )
 
+    def test_0060_warehouse_quantity(self):
+        """
+        Test that product sale is affected by availability and warehouse
+        quantity
+        """
+        StockMove = POOL.get('stock.move')
+        Website = POOL.get('nereid.website')
+        Location = POOL.get('stock.location')
+        SaleLine = POOL.get('sale.line')
+
+        with Transaction().start(DB_NAME, USER, CONTEXT):
+            self.setup_defaults()
+            app = self.get_app()
+
+            website, = Website.search([])
+            supplier, = Location.search([('code', '=', 'SUP')])
+            stock1, = StockMove.create([{
+                'product': self.product1.id,
+                'uom': self.template1.sale_uom.id,
+                'quantity': 10,
+                'from_location': supplier,
+                'to_location': website.stock_location.id,
+                'company': website.company.id,
+                'unit_price': Decimal('1'),
+                'currency': website.currencies[0].id,
+                'planned_date': datetime.date.today(),
+                'effective_date': datetime.date.today(),
+                'state': 'draft',
+            }])
+            StockMove.write([stock1], {
+                'state': 'done'
+            })
+
+            headers = Headers([('Referer', '/')])
+
+            # Set product warehouse quantity
+            self.product1.min_warehouse_quantity = 11
+            self.product1.save()
+
+            with app.test_client() as c:
+                self.login(c, 'email@example.com', 'password')
+
+                rv = c.post(
+                    '/cart/add',
+                    data={
+                        'product': self.product1.id, 'quantity': 5
+                    },
+                    headers=headers
+                )
+                # Cannot add to cart, available quantity < warehouse quantity
+                self.assertTrue(rv.location.endswith('/'))
+                self.assertEqual(rv.status_code, 302)
+                self.assertEqual(SaleLine.search([], count=True), 0)
+
+            # Try a service product
+            self.product1.template.type = 'service'
+            self.product1.template.save()
+
+            with app.test_client() as c:
+                self.login(c, 'email@example.com', 'password')
+
+                rv = c.post(
+                    '/cart/add',
+                    data={
+                        'product': self.product1.id, 'quantity': 5
+                    },
+                )
+                # Add to cart proceeds normally
+                self.assertTrue(rv.location.endswith('/cart'))
+                self.assertEqual(rv.status_code, 302)
+                self.assertEqual(SaleLine.search([], count=True), 1)
+
 
 def suite():
     "Cart test suite"
